@@ -21,8 +21,8 @@
 ###############################################################################
 
 .openCRstuff <- new.env()
-#.openCRstuff$packageType <- ' pre-release'
-.openCRstuff$packageType <- ''
+.openCRstuff$packageType <- ' pre-release'
+#.openCRstuff$packageType <- ''
 .openCRstuff$iter <- 0
 .openCRstuff$suspendedtypes <- c('JSSAfgCL', 'JSSAfg')
 
@@ -739,7 +739,6 @@ lpredictor <- function (model, newdata, indx, beta, field, beta.vcv=NULL,
   
   # new wrapper function 2021-07-23
   mat <- get.model.matrix (model, field, newdata, validlevels, contrasts)
-  
   # if (field=='b') browser()  
   
   ## drop pmix beta0 column from design matrix (always zero)
